@@ -1,7 +1,11 @@
 package Perinci::Sub::XCompletionBundle::Color;
 
-our $DATE = '2018-09-26'; # DATE
-our $VERSION = '0.001'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-12-01'; # DATE
+our $DIST = 'Perinci-Sub-XCompletionBundle-Color'; # DIST
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Completion routines related to color schemas
@@ -18,7 +22,7 @@ Perinci::Sub::XCompletionBundle::Color - Completion routines related to color sc
 
 =head1 VERSION
 
-This document describes version 0.001 of Perinci::Sub::XCompletionBundle::Color (from Perl distribution Perinci-Sub-XCompletionBundle-Color), released on 2018-09-26.
+This document describes version 0.002 of Perinci::Sub::XCompletionBundle::Color (from Perl distribution Perinci-Sub-XCompletionBundle-Color), released on 2023-12-01.
 
 =head1 HOMEPAGE
 
@@ -28,14 +32,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-XCompletionBundle-Color>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-XCompletionBundle-Color>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Sah::Schemas::Color>
@@ -44,11 +40,37 @@ L<Sah::Schemas::Color>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2023, 2018 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-XCompletionBundle-Color>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
